summaryrefslogtreecommitdiffstats
path: root/sys/contrib/dev/acpica/osunixxf.c
diff options
context:
space:
mode:
Diffstat (limited to 'sys/contrib/dev/acpica/osunixxf.c')
-rw-r--r--sys/contrib/dev/acpica/osunixxf.c105
1 files changed, 74 insertions, 31 deletions
diff --git a/sys/contrib/dev/acpica/osunixxf.c b/sys/contrib/dev/acpica/osunixxf.c
index b693305..8fc21fc 100644
--- a/sys/contrib/dev/acpica/osunixxf.c
+++ b/sys/contrib/dev/acpica/osunixxf.c
@@ -8,7 +8,7 @@
*
* 1. Copyright Notice
*
- * Some or all of this work - Copyright (c) 1999 - 2005, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2007, Intel Corp.
* All rights reserved.
*
* 2. License
@@ -130,8 +130,6 @@
#include <contrib/dev/acpica/acparser.h>
#include <contrib/dev/acpica/acdebug.h>
-#include <contrib/dev/acpica/compiler/aslcompiler.h>
-
#define _COMPONENT ACPI_OS_SERVICES
ACPI_MODULE_NAME ("osunixxf")
@@ -139,6 +137,10 @@
extern FILE *AcpiGbl_DebugFile;
FILE *AcpiGbl_OutputFile;
+ACPI_PHYSICAL_ADDRESS
+AeLocalGetRootPointer (
+ void);
+
/******************************************************************************
*
@@ -172,22 +174,20 @@ AcpiOsTerminate (void)
*
* FUNCTION: AcpiOsGetRootPointer
*
- * PARAMETERS: Flags - Logical or physical addressing mode
- * Address - Where the address is returned
+ * PARAMETERS: None
*
- * RETURN: Status
+ * RETURN: RSDP physical address
*
* DESCRIPTION: Gets the root pointer (RSDP)
*
*****************************************************************************/
-ACPI_STATUS
+ACPI_PHYSICAL_ADDRESS
AcpiOsGetRootPointer (
- UINT32 Flags,
- ACPI_POINTER *Address)
+ void)
{
- return (AeLocalGetRootPointer(Flags, Address));
+ return (AeLocalGetRootPointer ());
}
@@ -252,7 +252,7 @@ AcpiOsTableOverride (
/* This code exercises the table override mechanism in the core */
- if (!ACPI_STRNCMP (ExistingTable->Signature, DSDT_SIG, ACPI_NAME_SIZE))
+ if (ACPI_COMPARE_NAME (ExistingTable->Signature, ACPI_SIG_DSDT))
{
/* override DSDT with itself */
@@ -458,7 +458,6 @@ AcpiOsGetLine (
*
* PARAMETERS: where Physical address of memory to be mapped
* length How much memory to map
- * there Logical address of mapped memory
*
* RETURN: Pointer to mapped memory. Null on error.
*
@@ -466,15 +465,13 @@ AcpiOsGetLine (
*
*****************************************************************************/
-ACPI_STATUS
+void *
AcpiOsMapMemory (
ACPI_PHYSICAL_ADDRESS where,
- ACPI_SIZE length,
- void **there)
+ ACPI_SIZE length)
{
- *there = ACPI_TO_POINTER (where);
- return AE_OK;
+ return (ACPI_TO_POINTER ((ACPI_NATIVE_UINT) where));
}
@@ -652,7 +649,7 @@ AcpiOsSignalSemaphore (
ACPI_STATUS
AcpiOsCreateLock (
- ACPI_HANDLE *OutHandle)
+ ACPI_SPINLOCK *OutHandle)
{
return (AcpiOsCreateSemaphore (1, 1, OutHandle));
@@ -660,13 +657,13 @@ AcpiOsCreateLock (
void
AcpiOsDeleteLock (
- ACPI_HANDLE Handle)
+ ACPI_SPINLOCK Handle)
{
AcpiOsDeleteSemaphore (Handle);
}
-ACPI_NATIVE_UINT
+ACPI_CPU_FLAGS
AcpiOsAcquireLock (
ACPI_HANDLE Handle)
{
@@ -677,8 +674,8 @@ AcpiOsAcquireLock (
void
AcpiOsReleaseLock (
- ACPI_HANDLE Handle,
- ACPI_NATIVE_UINT Flags)
+ ACPI_SPINLOCK Handle,
+ ACPI_CPU_FLAGS Flags)
{
AcpiOsSignalSemaphore (Handle, 1);
}
@@ -735,21 +732,21 @@ AcpiOsRemoveInterruptHandler (
/******************************************************************************
*
- * FUNCTION: AcpiOsQueueForExecution
+ * FUNCTION: AcpiOsExecute
*
* PARAMETERS: Priority - Requested execution priority
* Function - Address of the function to execute
* Context - Passed as a parameter to the function
*
* RETURN: Status.
*
- * DESCRIPTION: Sleep at microsecond granularity
+ * DESCRIPTION: Execute a new thread
*
*****************************************************************************/
ACPI_STATUS
-AcpiOsQueueForExecution (
- UINT32 Priority,
+AcpiOsExecute (
+ ACPI_EXECUTE_TYPE Type,
ACPI_OSD_EXEC_CALLBACK Function,
void *Context)
{
@@ -776,8 +773,6 @@ AcpiOsBreakpoint (
char *Msg)
{
- /* Print the message and do an INT 3 */
-
if (Msg)
{
AcpiOsPrintf ("AcpiOsBreakpoint: %s ****\n", Msg);
@@ -787,7 +782,6 @@ AcpiOsBreakpoint (
AcpiOsPrintf ("At AcpiOsBreakpoint ****\n");
}
-
return AE_OK;
}
@@ -871,6 +865,55 @@ AcpiOsGetTimer (void)
/******************************************************************************
*
+ * FUNCTION: AcpiOsValidateInterface
+ *
+ * PARAMETERS: Interface - Requested interface to be validated
+ *
+ * RETURN: AE_OK if interface is supported, AE_SUPPORT otherwise
+ *
+ * DESCRIPTION: Match an interface string to the interfaces supported by the
+ * host. Strings originate from an AML call to the _OSI method.
+ *
+ *****************************************************************************/
+
+ACPI_STATUS
+AcpiOsValidateInterface (
+ char *Interface)
+{
+
+ return (AE_SUPPORT);
+}
+
+
+/******************************************************************************
+ *
+ * FUNCTION: AcpiOsValidateAddress
+ *
+ * PARAMETERS: SpaceId - ACPI space ID
+ * Address - Physical address
+ * Length - Address length
+ *
+ * RETURN: AE_OK if Address/Length is valid for the SpaceId. Otherwise,
+ * should return AE_AML_ILLEGAL_ADDRESS.
+ *
+ * DESCRIPTION: Validate a system address via the host OS. Used to validate
+ * the addresses accessed by AML operation regions.
+ *
+ *****************************************************************************/
+
+ACPI_STATUS
+AcpiOsValidateAddress (
+ UINT8 SpaceId,
+ ACPI_PHYSICAL_ADDRESS Address,
+ ACPI_SIZE Length)
+{
+
+ return (AE_OK);
+}
+
+
+/******************************************************************************
+ *
* FUNCTION: AcpiOsReadPciConfiguration
*
* PARAMETERS: PciId Seg/Bus/Dev
@@ -1060,7 +1103,7 @@ AcpiOsWriteMemory (
}
-UINT32
+ACPI_THREAD_ID
AcpiOsGetThreadId(void)
{
return getpid();
@@ -735,21 +732,21 @@ AcpiOsRemoveInterruptHandler (
*
- * PARAMETERS: Priority - Requested execution priority
+ * PARAMETERS: Type - Type of execution
* Function - Address of the function to execute
* Context - Passed as a parameter to the function
OpenPOWER on IntegriCloud